{% load staticfiles %}
<meta http-equiv="X-UA-Compatible" content="IE=edge" />
<meta name="viewport" content="width=device-width, initial-scale=1.0" />
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<script type="text/javascript" src="{% static 'instant/frontend/js/vue.min.js' %}"></script>
<script type="text/javascript" src="{% static 'instant/frontend/js/vuex.js' %}"></script>
<script type="text/javascript" src="{% static 'instant/frontend/js/axios.min.js' %}"></script>
<script type="text/javascript" src="{% static 'instant/frontend/js/vv.min.js' %}"></script>
<link rel="stylesheet" media="screen, projection" href="https://maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css" />
<link rel="stylesheet" media="screen, projection" href="https://cdn.rawgit.com/franciscop/picnic/1c4f7c98/releases/picnic.min.css" />
<link rel="stylesheet" media="screen, projection" href="{% static 'instant/frontend/css/instant.css' %}" />
<link rel="stylesheet" media="screen, projection" href="{% static 'instant/frontend/css/labels.css' %}" />